@@ -24,7 +24,7 @@ from starlite.utils import normalize_path
 
 if TYPE_CHECKING:  # pragma: no cover
     from starlite.controller import Controller
-    from starlite.routing import Router
+    from starlite.router import Router
 
 
 class BaseRouteHandler:
